@@ -46,8 +46,17 @@ const long avVersionEditorDlg::ID_REVISIONRANDOM_TEXT = wxNewId();
 const long avVersionEditorDlg::ID_BUILDTIMES_LABEL = wxNewId();
 const long avVersionEditorDlg::ID_BUILDTIMES_TEXT = wxNewId();
 const long avVersionEditorDlg::ID_SCHEME_PANEL = wxNewId();
+const long avVersionEditorDlg::ID_HEADER_GUARD_LABEL = wxNewId();
+const long avVersionEditorDlg::ID_HEADER_GUARD_TEXT = wxNewId();
+const long avVersionEditorDlg::ID_NAMESPACE_LABEL = wxNewId();
+const long avVersionEditorDlg::ID_NAMESPACE_TEXT = wxNewId();
+const long avVersionEditorDlg::ID_PREFIX_LABEL = wxNewId();
+const long avVersionEditorDlg::ID_PREFIX_TEXT = wxNewId();
+const long avVersionEditorDlg::ID_CODE_PANEL = wxNewId();
 const long avVersionEditorDlg::ID_AUTO_CHECK = wxNewId();
 const long avVersionEditorDlg::ID_DATES_CHECK = wxNewId();
+const long avVersionEditorDlg::ID_DEFINE_CHECK = wxNewId();
+const long avVersionEditorDlg::ID_UPDATE_MANIFEST = wxNewId();
 const long avVersionEditorDlg::ID_COMMIT_CHECK = wxNewId();
 const long avVersionEditorDlg::ID_ASKCOMMIT_CHECK = wxNewId();
 const long avVersionEditorDlg::ID_STATICLINE3 = wxNewId();
@@ -78,14 +87,14 @@ const long avVersionEditorDlg::ID_VALIDATE_TIMER = wxNewId();
 //}
 
 //{Events
-BEGIN_EVENT_TABLE(avVersionEditorDlg,wxDialog)
+BEGIN_EVENT_TABLE(avVersionEditorDlg,wxScrollingDialog)
     //(*EventTable(avVersionEditorDlg)
     //*)
 END_EVENT_TABLE()
 //}
 
 //{Constructor and Destructor
-avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
+avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID /*id*/)
 {
     //(*Initialize(avVersionEditorDlg)
     wxBoxSizer* BoxSizer15;
@@ -93,6 +102,7 @@ avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
     wxBoxSizer* BoxSizer13;
     wxBoxSizer* BoxSizer11;
     wxBoxSizer* BoxSizer14;
+    wxBoxSizer* codeSizer;
 
     Create(parent, wxID_ANY, _("Auto Versioning Editor"), wxDefaultPosition, wxDefaultSize, wxCAPTION|wxRESIZE_BORDER, _T("wxID_ANY"));
     SetClientSize(wxSize(469,364));
@@ -150,7 +160,7 @@ avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
     lblStatus = new wxStaticText(pnlStatus, ID_SATUS_LABEL, _("Software Status:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_SATUS_LABEL"));
     statusSizer->Add(lblStatus, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     cmbStatus = new wxComboBox(pnlStatus, ID_STATUS_COMBOBOX, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, 0, 0, wxDefaultValidator, _T("ID_STATUS_COMBOBOX"));
-    cmbStatus->SetSelection( cmbStatus->Append(_("Alpha")) );
+    cmbStatus->Append(_("Alpha"));
     cmbStatus->Append(_("Beta"));
     cmbStatus->Append(_("Release"));
     cmbStatus->Append(_("Release Candidate"));
@@ -162,7 +172,7 @@ avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
     StaticText1 = new wxStaticText(pnlStatus, ID_STATICTEXT1, _("Abbreviation:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_STATICTEXT1"));
     statusSizer->Add(StaticText1, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     cmbAbbreviation = new wxComboBox(pnlStatus, ID_ABBREVIATION_COMBOBOX, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, 0, 0, wxDefaultValidator, _T("ID_ABBREVIATION_COMBOBOX"));
-    cmbAbbreviation->SetSelection( cmbAbbreviation->Append(_("a")) );
+    cmbAbbreviation->Append(_("a"));
     cmbAbbreviation->Append(_("b"));
     cmbAbbreviation->Append(_("r"));
     cmbAbbreviation->Append(_("rc"));
@@ -210,6 +220,23 @@ avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
     pnlScheme->SetSizer(schemeSizer);
     schemeSizer->Fit(pnlScheme);
     schemeSizer->SetSizeHints(pnlScheme);
+    pnlCode = new wxPanel(nbAutoVersioning, ID_CODE_PANEL, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL, _T("ID_CODE_PANEL"));
+    codeSizer = new wxBoxSizer(wxVERTICAL);
+    lblHeaderGuard = new wxStaticText(pnlCode, ID_HEADER_GUARD_LABEL, _("Header guard:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_HEADER_GUARD_LABEL"));
+    codeSizer->Add(lblHeaderGuard, 0, wxALL|wxALIGN_LEFT|wxALIGN_TOP, 5);
+    txtHeaderGuard = new wxTextCtrl(pnlCode, ID_HEADER_GUARD_TEXT, _("VERSION_H"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_HEADER_GUARD_TEXT"));
+    codeSizer->Add(txtHeaderGuard, 0, wxALL|wxEXPAND|wxALIGN_LEFT|wxALIGN_TOP, 5);
+    lblNamespace = new wxStaticText(pnlCode, ID_NAMESPACE_LABEL, _("Namespace:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_NAMESPACE_LABEL"));
+    codeSizer->Add(lblNamespace, 0, wxALL|wxALIGN_LEFT|wxALIGN_TOP, 5);
+    txtNameSpace = new wxTextCtrl(pnlCode, ID_NAMESPACE_TEXT, _("AutoVersion"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_NAMESPACE_TEXT"));
+    codeSizer->Add(txtNameSpace, 0, wxALL|wxEXPAND|wxALIGN_LEFT|wxALIGN_TOP, 5);
+    lblPrefix = new wxStaticText(pnlCode, ID_PREFIX_LABEL, _("Variables prefix:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_PREFIX_LABEL"));
+    codeSizer->Add(lblPrefix, 0, wxALL|wxALIGN_LEFT|wxALIGN_TOP, 5);
+    txtPrefix = new wxTextCtrl(pnlCode, ID_PREFIX_TEXT, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_PREFIX_TEXT"));
+    codeSizer->Add(txtPrefix, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    pnlCode->SetSizer(codeSizer);
+    codeSizer->Fit(pnlCode);
+    codeSizer->SetSizeHints(pnlCode);
     pnlSettings = new wxPanel(nbAutoVersioning, ID_SETTINGS_PANEL, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL, _T("ID_SETTINGS_PANEL"));
     settingsSizer = new wxBoxSizer(wxVERTICAL);
     BoxSizer11 = new wxBoxSizer(wxHORIZONTAL);
@@ -222,6 +249,14 @@ avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
     chkDates->SetValue(true);
     chkDates->SetToolTip(_("Create variable declarations\nfor date, month and year. And \nalso an ubuntu version style."));
     BoxSizer13->Add(chkDates, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    chkDefine = new wxCheckBox(pnlSettings, ID_DEFINE_CHECK, _("Use #define"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_DEFINE_CHECK"));
+    chkDefine->SetValue(true);
+    chkDefine->SetToolTip(_("Use #define declaration instead of static variables"));
+    BoxSizer13->Add(chkDefine, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    chkUpdateManifest = new wxCheckBox(pnlSettings, ID_UPDATE_MANIFEST, _("Update manifest.xml"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_UPDATE_MANIFEST"));
+    chkUpdateManifest->SetValue(false);
+    chkUpdateManifest->SetToolTip(_("Update manifest.xml\'s version field with AutoVersion\'s\nvalues using the format MAJOR.MINOR.BUILD.\nThis setting is mainly useful for plugin developers."));
+    BoxSizer13->Add(chkUpdateManifest, 1, wxALL|wxALIGN_LEFT|wxALIGN_BOTTOM, 5);
     BoxSizer11->Add(BoxSizer13, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     BoxSizer14 = new wxBoxSizer(wxVERTICAL);
     chkCommit = new wxCheckBox(pnlSettings, ID_COMMIT_CHECK, _("Do Autoincrement"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_COMMIT_CHECK"));
@@ -233,6 +268,7 @@ avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
     chkAskCommit->Disable();
     chkAskCommit->SetToolTip(_("Ask you to increment every time\na change has been made to the \nsource code, before the compilation\ntakes effect."));
     BoxSizer14->Add(chkAskCommit, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
+    BoxSizer14->Add(-1,-1,1, wxALL|wxALIGN_LEFT|wxALIGN_BOTTOM, 5);
     BoxSizer11->Add(BoxSizer14, 0, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     settingsSizer->Add(BoxSizer11, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     StaticLine3 = new wxStaticLine(pnlSettings, ID_STATICLINE3, wxDefaultPosition, wxSize(10,-1), wxLI_HORIZONTAL, _T("ID_STATICLINE3"));
@@ -242,7 +278,7 @@ avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
     lblHeaderPath = new wxStaticText(pnlSettings, ID_HEADERPATH_LABEL, _("Header Path:"), wxDefaultPosition, wxDefaultSize, 0, _T("ID_HEADERPATH_LABEL"));
     BoxSizer7->Add(lblHeaderPath, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     BoxSizer15 = new wxBoxSizer(wxHORIZONTAL);
-    txtHeaderPath = new wxTextCtrl(pnlSettings, ID_HEADERPATH_TEXTCTRL, _("verison.h"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_HEADERPATH_TEXTCTRL"));
+    txtHeaderPath = new wxTextCtrl(pnlSettings, ID_HEADERPATH_TEXTCTRL, _("version.h"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_HEADERPATH_TEXTCTRL"));
     txtHeaderPath->SetToolTip(_("Header path"));
     BoxSizer15->Add(txtHeaderPath, 1, wxALL|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     btnHeaderPath = new wxButton(pnlSettings, ID_HEADERPATH_BUTTON, _("..."), wxDefaultPosition, wxSize(23,26), 0, wxDefaultValidator, _T("ID_HEADERPATH_BUTTON"));
@@ -251,10 +287,10 @@ avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
     BoxSizer7->Add(BoxSizer15, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     BoxSizer5->Add(BoxSizer7, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     BoxSizer8 = new wxBoxSizer(wxHORIZONTAL);
-    wxString __wxRadioBoxChoices_1[2] = 
+    wxString __wxRadioBoxChoices_1[2] =
     {
-        _("C"),
-        _("C++")
+    _("C"),
+    _("C++")
     };
     rbHeaderLanguage = new wxRadioBox(pnlSettings, ID_HEADERLANGUAGE_RADIOBOX, _("Header language"), wxDefaultPosition, wxDefaultSize, 2, __wxRadioBoxChoices_1, 2, wxRA_HORIZONTAL, wxDefaultValidator, _T("ID_HEADERLANGUAGE_RADIOBOX"));
     rbHeaderLanguage->SetSelection(1);
@@ -264,7 +300,7 @@ avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
     settingsSizer->Add(BoxSizer5, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     StaticLine1 = new wxStaticLine(pnlSettings, ID_STATICLINE1, wxDefaultPosition, wxSize(10,-1), wxLI_HORIZONTAL, _T("ID_STATICLINE1"));
     settingsSizer->Add(StaticLine1, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-    chkSvn = new wxCheckBox(pnlSettings, ID_SVN_CHECK, _("svn enabled"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_SVN_CHECK"));
+    chkSvn = new wxCheckBox(pnlSettings, ID_SVN_CHECK, _("SVN enabled"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_SVN_CHECK"));
     chkSvn->SetValue(false);
     chkSvn->SetToolTip(_("Check this if your project is controlled by svn\nto generate an SVN_REVISION declaration."));
     settingsSizer->Add(chkSvn, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 2);
@@ -281,7 +317,7 @@ avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
     pnlSettings->SetSizer(settingsSizer);
     settingsSizer->Fit(pnlSettings);
     settingsSizer->SetSizeHints(pnlSettings);
-    pnlChanges = new wxPanel(nbAutoVersioning, ID_CHANGES_PANEL, wxPoint(231,17), wxDefaultSize, wxTAB_TRAVERSAL, _T("ID_CHANGES_PANEL"));
+    pnlChanges = new wxPanel(nbAutoVersioning, ID_CHANGES_PANEL, wxDefaultPosition, wxDefaultSize, wxTAB_TRAVERSAL, _T("ID_CHANGES_PANEL"));
     changesSizer = new wxBoxSizer(wxVERTICAL);
     chkChanges = new wxCheckBox(pnlChanges, ID_GENERATECHANGES_CHECKBOX, _("Show changes editor when incrementing version"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_GENERATECHANGES_CHECKBOX"));
     chkChanges->SetValue(false);
@@ -311,10 +347,11 @@ avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
     nbAutoVersioning->AddPage(pnlVersionValues, _("Version Values"), true);
     nbAutoVersioning->AddPage(pnlStatus, _("Status"), false);
     nbAutoVersioning->AddPage(pnlScheme, _("Scheme"), false);
+    nbAutoVersioning->AddPage(pnlCode, _("Code"), false);
     nbAutoVersioning->AddPage(pnlSettings, _("Settings"), false);
     nbAutoVersioning->AddPage(pnlChanges, _("Changes Log"), false);
     mainSizer->Add(nbAutoVersioning, 1, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
-    lblCurrentProject = new wxStaticText(this, ID_STATICTEXT2, _("Current Project: "), wxDefaultPosition, wxDefaultSize, wxALIGN_CENTRE, _T("ID_STATICTEXT2"));
+    lblCurrentProject = new wxStaticText(this, ID_STATICTEXT2, _("Current Project:"), wxDefaultPosition, wxDefaultSize, wxALIGN_CENTRE, _T("ID_STATICTEXT2"));
     mainSizer->Add(lblCurrentProject, 0, wxALL|wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxALIGN_CENTER_VERTICAL, 5);
     buttonsSizer = new wxBoxSizer(wxHORIZONTAL);
     btnAccept = new wxButton(this, ID_ACCEPT, _("&Accept"), wxDefaultPosition, wxDefaultSize, 0, wxDefaultValidator, _T("ID_ACCEPT"));
@@ -341,7 +378,7 @@ avVersionEditorDlg::avVersionEditorDlg(wxWindow* parent,wxWindowID id)
     Connect(ID_ACCEPT,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&avVersionEditorDlg::OnAcceptClick);
     Connect(ID_CANCEL,wxEVT_COMMAND_BUTTON_CLICKED,(wxObjectEventFunction)&avVersionEditorDlg::OnCancelClick);
     Connect(ID_VALIDATE_TIMER,wxEVT_TIMER,(wxObjectEventFunction)&avVersionEditorDlg::OnTmrValidateInputTrigger);
-    Connect(wxID_ANY,wxEVT_ENTER_WINDOW,(wxObjectEventFunction)&avVersionEditorDlg::OnMouseEnter);
+    Connect(wxEVT_ENTER_WINDOW,(wxObjectEventFunction)&avVersionEditorDlg::OnMouseEnter);
     //*)
 
     tmrValidateInput.Stop();
@@ -360,7 +397,7 @@ void avVersionEditorDlg::SetMajor(long value)
 {
     m_major = value;
     wxString strValue;
-    strValue.Printf(_T("%d"),value);
+    strValue.Printf(_T("%ld"),value);
     txtMajorVersion->SetValue(strValue);
 }
 
@@ -368,7 +405,7 @@ void avVersionEditorDlg::SetMinor(long value)
 {
     m_minor = value;
     wxString strValue;
-    strValue.Printf(_T("%d"),value);
+    strValue.Printf(_T("%ld"),value);
     txtMinorVersion->SetValue(strValue);
 }
 
@@ -376,7 +413,7 @@ void avVersionEditorDlg::SetBuild(long value)
 {
     m_build = value;
     wxString strValue;
-    strValue.Printf(_T("%d"),value);
+    strValue.Printf(_T("%ld"),value);
     txtBuildNumber->SetValue(strValue);
 }
 
@@ -384,7 +421,7 @@ void avVersionEditorDlg::SetRevision(long value)
 {
     m_revision = value;
     wxString strValue;
-    strValue.Printf(_T("%d"),value);
+    strValue.Printf(_T("%ld"),value);
     txtRevisionNumber->SetValue(strValue);
 }
 
@@ -392,7 +429,7 @@ void avVersionEditorDlg::SetCount(long value)
 {
     m_count = value;
     wxString strValue;
-    strValue.Printf(_T("%d"),value);
+    strValue.Printf(_T("%ld"),value);
     txtBuildCount->SetValue(strValue);
 }
 //}
@@ -410,6 +447,19 @@ void avVersionEditorDlg::SetDates(bool value)
 	chkDates->SetValue(value);
 }
 
+void avVersionEditorDlg::SetDefine(bool value)
+{
+	m_useDefine = value;
+	chkDefine->SetValue(value);
+}
+
+// GJH 03/03/10 Added manifest updating.
+void avVersionEditorDlg::SetManifest(bool value)
+{
+	m_updateManifest = value;
+	chkUpdateManifest->SetValue(value);
+}
+
 void avVersionEditorDlg::SetSvn(bool value)
 {
 	m_svn = value;
@@ -496,7 +546,7 @@ void avVersionEditorDlg::SetMinorMaximum(long value)
 {
 	m_minorMaximun = value;
 	wxString strValue;
-	strValue.Printf(_T("%d"),value);
+	strValue.Printf(_T("%ld"),value);
 	txtMinorMaximun->SetValue(strValue);
 }
 
@@ -504,7 +554,7 @@ void avVersionEditorDlg::SetBuildMaximum(long value)
 {
 	m_buildMaximun = value;
 	wxString strValue;
-	strValue.Printf(_T("%d"),value);
+	strValue.Printf(_T("%ld"),value);
 	txtBuildNumberMaximun->SetValue(strValue);
 }
 
@@ -512,7 +562,7 @@ void avVersionEditorDlg::SetRevisionMaximum(long value)
 {
 	m_revisionMaximun = value;
 	wxString strValue;
-	strValue.Printf(_T("%d"),value);
+	strValue.Printf(_T("%ld"),value);
 	txtRevisionMax->SetValue(strValue);
 }
 
@@ -520,7 +570,7 @@ void avVersionEditorDlg::SetRevisionRandomMaximum(long value)
 {
 	m_revisionRandomMaximun = value;
 	wxString strValue;
-	strValue.Printf(_T("%d"),value);
+	strValue.Printf(_T("%ld"),value);
 	txtRevisionRandom->SetValue(strValue);
 }
 
@@ -528,7 +578,7 @@ void avVersionEditorDlg::SetBuildTimesToMinorIncrement(long value)
 {
 	m_buildTimesToMinorIncrement = value;
 	wxString strValue;
-	strValue.Printf(_T("%d"),value);
+	strValue.Printf(_T("%ld"),value);
 	txtBuildTimes->SetValue(strValue);
 }
 //}
@@ -556,6 +606,26 @@ void avVersionEditorDlg::SetChangesTitle(const wxString& value)
 }
 //}
 
+//{Code
+void avVersionEditorDlg::SetHeaderGuard(const wxString& value)
+{
+    m_headerGuard = value;
+    txtHeaderGuard->SetValue(value);
+}
+
+void avVersionEditorDlg::SetNamespace(const wxString& value)
+{
+    m_namespace = value;
+    txtNameSpace->SetValue(value);
+}
+
+void avVersionEditorDlg::SetPrefix(const wxString& value)
+{
+    m_prefix = value;
+    txtPrefix->SetValue(value);
+}
+//}
+
 void avVersionEditorDlg::SetCurrentProject(const wxString& projectName)
 {
     lblCurrentProject->SetLabel(lblCurrentProject->GetLabel() + projectName);
@@ -575,6 +645,9 @@ void avVersionEditorDlg::OnAcceptClick(wxCommandEvent&)
 
     m_autoMajorMinor = chkAutoIncrement->IsChecked();
     m_dates = chkDates->IsChecked();
+    m_useDefine = chkDefine->IsChecked();
+	// GJH 03/03/10 Added manifest updating.
+	m_updateManifest = chkUpdateManifest->IsChecked();
     m_svn = chkSvn->IsChecked();
     m_svnDirectory = txtSvnDir->GetValue();
     m_commit = chkCommit->IsChecked();
@@ -595,6 +668,10 @@ void avVersionEditorDlg::OnAcceptClick(wxCommandEvent&)
     m_changesTitle = txtChangesTitle->GetValue();
     m_changesLogPath = txtChangesLogPath->GetValue();
 
+    m_headerGuard = txtHeaderGuard->GetValue();
+    m_namespace = txtNameSpace->GetValue();
+    m_prefix = txtPrefix->GetValue();
+
     EndModal(0);
 }
 
@@ -742,17 +819,17 @@ void avVersionEditorDlg::ValidateInput()
     }
 }
 
-void avVersionEditorDlg::OnTmrValidateInputTrigger(wxTimerEvent& event)
+void avVersionEditorDlg::OnTmrValidateInputTrigger(wxTimerEvent& /*event*/)
 {
     ValidateInput();
 }
 
-void avVersionEditorDlg::OnMouseEnter(wxMouseEvent& event)
+void avVersionEditorDlg::OnMouseEnter(wxMouseEvent& /*event*/)
 {
     tmrValidateInput.Start(250, false);
 }
 
-void avVersionEditorDlg::OnHeaderPathClick(wxCommandEvent& event)
+void avVersionEditorDlg::OnHeaderPathClick(wxCommandEvent& /*event*/)
 {
     wxString path, filename, extension;
     wxFileName::SplitPath(m_headerPath, &path, &filename, &extension);
@@ -769,7 +846,7 @@ void avVersionEditorDlg::OnHeaderPathClick(wxCommandEvent& event)
     }
 }
 
-void avVersionEditorDlg::OnChangesLogPathClick(wxCommandEvent& event)
+void avVersionEditorDlg::OnChangesLogPathClick(wxCommandEvent& /*event*/)
 {
     wxString path, filename, extension;
     wxFileName::SplitPath(m_changesLogPath, &path, &filename, &extension);
